==> qtjambi-charts-debuginfo-macos-6.5.7.jar: sources/QtJambiCharts/QVBarModelMapper_shell.h <==
#ifndef QVBARMODELMAPPER_SHELL_H
#define QVBARMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qvbarmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractbarseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QVBarModelMapper_shell : public QVBarModelMapper, public QtJambiShellInterface
{
public:
    QVBarModelMapper_shell(QObject* parent0 = nullptr);
    ~QVBarModelMapper_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QVBarModelMapper_mshell;
    friend class QVBarModelMapper_oshell;
};


class QVBarModelMapper_mshell : public QVBarModelMapper_shell
{
public:
    using QVBarModelMapper_shell::QVBarModelMapper_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QVBarModelMapper_oshell : public QVBarModelMapper_mshell
{
public:
    using QVBarModelMapper_mshell::QVBarModelMapper_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVBarModelMapper_access : public QVBarModelMapper
{
};

#endif // QVBARMODELMAPPER_SHELL_H

==> qtjambi-charts-debuginfo-macos-6.7.0.jar: sources/QtJambiCharts/QVBarModelMapper_shell.h <==
#ifndef QVBARMODELMAPPER_SHELL_H
#define QVBARMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qvbarmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractbarseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QVBarModelMapper_shell : public QVBarModelMapper, public QtJambiShellInterface
{
public:
    QVBarModelMapper_shell(QObject* parent0 = nullptr);
    ~QVBarModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVBarModelMapper_access : public QVBarModelMapper
{
};

#endif // QVBARMODELMAPPER_SHELL_H
